@@ -12,12 +12,12 @@
 #include <QHash>
 #include <QList>
 
-
 #include "indexfinder.h"
 
 #include "proxymodeltestsuite_export.h"
 
-template<typename T> class QList;
+template<typename T>
+class QList;
 
 class ModelMoveCommand;
 
@@ -28,7 +28,7 @@ public:
     enum Roles {
         DynamicTreeModelId = Qt::UserRole,
 
-        LastRole
+        LastRole,
     };
 
     explicit DynamicTreeModel(QObject *parent = nullptr);
@@ -46,7 +46,10 @@ public:
     Qt::DropActions supportedDropActions() const override;
     QStringList mimeTypes() const override;
     QMimeData *mimeData(const QModelIndexList &indexes) const override;
-    QModelIndexList match(const QModelIndex &start, int role, const QVariant &value, int hits = 1,
+    QModelIndexList match(const QModelIndex &start,
+                          int role,
+                          const QVariant &value,
+                          int hits = 1,
                           Qt::MatchFlags flags = Qt::MatchFlags(Qt::MatchStartsWith | Qt::MatchWrap)) const override;
 
     void clear();
@@ -55,8 +58,8 @@ public:
 
 protected Q_SLOTS:
 
-    /**
-    Finds the parent id of the string with id @p searchId.
+    /*!
+    Finds the parent id of the string with id \a searchId.
 
     Returns -1 if not found.
     */
@@ -64,7 +67,7 @@ protected Q_SLOTS:
 
 private:
     QHash<qint64, QString> m_items;
-    QHash<qint64, QList<QList<qint64> > > m_childItems;
+    QHash<qint64, QList<QList<qint64>>> m_childItems;
     qint64 nextId;
     qint64 newId()
     {
@@ -85,20 +88,20 @@ private:
     friend class ModelMoveLayoutChangeCommand;
     friend class ModelResetCommand;
     friend class ModelLayoutChangeCommand;
-//   friend class ModelSortIndexCommand;
+    //   friend class ModelSortIndexCommand;
     friend class ModelSortIndexLayoutChangeCommand;
     friend class ModelInsertAndRemoveQueuedCommand;
-
 };
 
 class PROXYMODELTESTSUITE_EXPORT ModelChangeCommand : public QObject
 {
     Q_OBJECT
 public:
-
     ModelChangeCommand(DynamicTreeModel *model, QObject *parent = nullptr);
 
-    virtual ~ModelChangeCommand() {}
+    ~ModelChangeCommand() override
+    {
+    }
 
     void setAncestorRowNumbers(const QList<int> &rowNumbers)
     {
@@ -147,20 +150,19 @@ protected:
     int m_startRow;
     int m_endRow;
     int m_numCols;
-
 };
 
 typedef QList<ModelChangeCommand *> ModelChangeCommandList;
 
-/**
-  @brief Inserts a sub tree into the dynamictreemodel.
+/*!
+  \brief Inserts a sub tree into the dynamictreemodel.
 
   As an alternative to setStartRow and setEndRow, the interpret command may be used.
 
   The interpret command is used to set the structure of the subtree.
 
   For example,
-  @code
+  \code
   cmd = new ModelInsertCommand(m_model, this);
   cmd->interpret(
     "- A"
@@ -168,13 +170,13 @@ typedef QList<ModelChangeCommand *> ModelChangeCommandList;
     "- - C"
     "- D"
   );
-  @endcode
+  \endcode
 
   Will emit an insert for 3 rows, the second of which will have a child row. The interpretation
   string may be complex as long as it is valid. The text at the end of each row does not need to be consistent.
   There is a define DUMPTREE to make this command print the tree it inserts for better readability.
 
-  @code
+  \code
   cmd->interpret(
     "- A"
     "- - B"
@@ -188,32 +190,36 @@ typedef QList<ModelChangeCommand *> ModelChangeCommandList;
     "- - E"
     "- - F"
   );
-  @endcode
+  \endcode
 
   The string is valid if (depth of row (N + 1)) <= ( (depth of row N) + 1). For example, the following is invalid
   because the depth of B is 2 and the depth of A is 0.
 
-  @code
+  \code
   cmd->interpret(
     "- A"
     "- - - B"
     "- - C"
-  @endcode
+  \endcode
 */
 class PROXYMODELTESTSUITE_EXPORT ModelInsertCommand : public ModelChangeCommand
 {
     Q_OBJECT
 
     struct Token {
-        enum Type { Branch, Leaf };
+        enum Type {
+            Branch,
+            Leaf,
+        };
         Type type;
         QString content;
     };
 
 public:
-
     explicit ModelInsertCommand(DynamicTreeModel *model, QObject *parent = nullptr);
-    virtual ~ModelInsertCommand() {}
+    ~ModelInsertCommand() override
+    {
+    }
 
     void interpret(const QString &treeString);
 
@@ -233,9 +239,10 @@ class PROXYMODELTESTSUITE_EXPORT ModelInsertAndRemoveQueuedCommand : public Mode
     Q_OBJECT
 
 public:
-
     explicit ModelInsertAndRemoveQueuedCommand(DynamicTreeModel *model, QObject *parent = nullptr);
-    virtual ~ModelInsertAndRemoveQueuedCommand() {}
+    ~ModelInsertAndRemoveQueuedCommand() override
+    {
+    }
 
     void doCommand() override;
 
@@ -260,7 +267,9 @@ class PROXYMODELTESTSUITE_EXPORT ModelRemoveCommand : public ModelChangeCommand
     Q_OBJECT
 public:
     explicit ModelRemoveCommand(DynamicTreeModel *model, QObject *parent = nullptr);
-    virtual ~ModelRemoveCommand() {}
+    ~ModelRemoveCommand() override
+    {
+    }
 
     void doCommand() override;
 
@@ -273,7 +282,9 @@ class PROXYMODELTESTSUITE_EXPORT ModelDataChangeCommand : public ModelChangeComm
 public:
     explicit ModelDataChangeCommand(DynamicTreeModel *model, QObject *parent = nullptr);
 
-    virtual ~ModelDataChangeCommand() {}
+    ~ModelDataChangeCommand() override
+    {
+    }
 
     void doCommand() override;
 
@@ -292,7 +303,9 @@ class PROXYMODELTESTSUITE_EXPORT ModelMoveCommand : public ModelChangeCommand
 public:
     explicit ModelMoveCommand(DynamicTreeModel *model, QObject *parent);
 
-    virtual ~ModelMoveCommand() {}
+    ~ModelMoveCommand() override
+    {
+    }
 
     virtual bool emitPreSignal(const QModelIndex &srcParent, int srcStart, int srcEnd, const QModelIndex &destParent, int destRow);
 
@@ -324,7 +337,7 @@ class PROXYMODELTESTSUITE_EXPORT ModelMoveLayoutChangeCommand : public ModelMove
     Q_OBJECT
 public:
     explicit ModelMoveLayoutChangeCommand(DynamicTreeModel *model, QObject *parent);
-    virtual ~ModelMoveLayoutChangeCommand();
+    ~ModelMoveLayoutChangeCommand() override;
 
     bool emitPreSignal(const QModelIndex &srcParent, int srcStart, int srcEnd, const QModelIndex &destParent, int destRow) override;
 
@@ -343,7 +356,6 @@ private:
     QModelIndexList m_beforeMoveList;
     QList<int> m_endOfMoveSourceAncestors;
     QList<int> m_endOfMoveDestAncestors;
-
 };
 
 class PROXYMODELTESTSUITE_EXPORT ModelResetCommand : public ModelChangeCommand
@@ -351,11 +363,12 @@ class PROXYMODELTESTSUITE_EXPORT ModelResetCommand : public ModelChangeCommand
     Q_OBJECT
 public:
     ModelResetCommand(DynamicTreeModel *model, QObject *parent = nullptr);
-    virtual ~ModelResetCommand();
+    ~ModelResetCommand() override;
 
     void setInitialTree(const QString &treeString);
 
     void doCommand() override;
+
 private:
     QString m_treeString;
 };
@@ -365,7 +378,7 @@ class PROXYMODELTESTSUITE_EXPORT ModelLayoutChangeCommand : public ModelChangeCo
     Q_OBJECT
 public:
     ModelLayoutChangeCommand(DynamicTreeModel *model, QObject *parent = nullptr);
-    virtual ~ModelLayoutChangeCommand();
+    ~ModelLayoutChangeCommand() override;
 
     struct PersistentChange {
         QList<int> oldPath;
@@ -377,6 +390,7 @@ public:
     void setInitialTree(const QString &treeString);
 
     void doCommand() override;
+
 private:
     QString m_treeString;
     QList<PersistentChange> m_changes;
