@@ -10,7 +10,7 @@
 class KRearrangeColumnsProxyModelPrivate
 {
 public:
-    QVector<int> m_sourceColumns;
+    QList<int> m_sourceColumns;
 };
 
 KRearrangeColumnsProxyModel::KRearrangeColumnsProxyModel(QObject *parent)
@@ -23,7 +23,7 @@ KRearrangeColumnsProxyModel::~KRearrangeColumnsProxyModel()
 {
 }
 
-void KRearrangeColumnsProxyModel::setSourceColumns(const QVector<int> &columns)
+void KRearrangeColumnsProxyModel::setSourceColumns(const QList<int> &columns)
 {
     // We could use layoutChanged() here, but we would have to map persistent
     // indexes from the old to the new location...
@@ -71,20 +71,10 @@ bool KRearrangeColumnsProxyModel::hasChildren(const QModelIndex &parent) const
     return sourceModel()->rowCount(sourceParent) > 0;
 }
 
-// We derive from QIdentityProxyModel simply to be able to use
-// its mapFromSource method which has friend access to createIndex() in the source model.
-
 QModelIndex KRearrangeColumnsProxyModel::index(int row, int column, const QModelIndex &parent) const
 {
     Q_ASSERT(parent.isValid() ? parent.model() == this : true);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     Q_ASSERT(row >= 0);
-#else
-    // workaround for QTreeView bug, fixed in https://codereview.qt-project.org/c/qt/qtbase/+/293092
-    if (row < 0) {
-        return {};
-    }
-#endif
     Q_ASSERT(column >= 0);
 
     // Only first column has children
@@ -158,14 +148,12 @@ QModelIndex KRearrangeColumnsProxyModel::mapToSource(const QModelIndex &proxyInd
     if (!proxyIndex.isValid()) {
         return QModelIndex();
     }
-    // This is just an indirect way to call sourceModel->createIndex(row, sourceColumn, pointer)
-    const QModelIndex fakeIndex = createIndex(proxyIndex.row(), sourceColumnForProxyColumn(proxyIndex.column()), proxyIndex.internalPointer());
-    return QIdentityProxyModel::mapToSource(fakeIndex);
+    return createSourceIndex(proxyIndex.row(), sourceColumnForProxyColumn(proxyIndex.column()), proxyIndex.internalPointer());
 }
 
 int KRearrangeColumnsProxyModel::proxyColumnForSourceColumn(int sourceColumn) const
 {
-    // If this is too slow, we could add a second QVector with index=logical_source_column value=desired_pos_in_proxy.
+    // If this is too slow, we could add a second QList with index=logical_source_column value=desired_pos_in_proxy.
     return d_ptr->m_sourceColumns.indexOf(sourceColumn);
 }
 
